Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(795)

Unified Diff: base/test/test_timeouts.h

Issue 476543004: Implement unit test specific test launcher timeout (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: after disabling Created 6 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « base/test/test_switches.cc ('k') | base/test/test_timeouts.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: base/test/test_timeouts.h
diff --git a/base/test/test_timeouts.h b/base/test/test_timeouts.h
index 2819e4a1c1170dab9332fb6b729707ca5058b6d7..5f7926417c0aa2aabd35aa0fb9be29ce4a5b5461 100644
--- a/base/test/test_timeouts.h
+++ b/base/test/test_timeouts.h
@@ -38,7 +38,14 @@ class TestTimeouts {
return base::TimeDelta::FromMilliseconds(action_max_timeout_ms_);
}
- // Timeout for a single test launched used built-in test launcher.
+ // Timeout for a single unit test launched using built-in test launcher.
+ // Do not use outside of the test launcher.
+ static base::TimeDelta test_launcher_unit_timeout() {
+ DCHECK(initialized_);
+ return base::TimeDelta::FromMilliseconds(test_launcher_unit_timeout_ms_);
+ }
+
+ // Timeout for a single test launched using built-in test launcher.
// Do not use outside of the test launcher.
static base::TimeDelta test_launcher_timeout() {
DCHECK(initialized_);
@@ -51,6 +58,7 @@ class TestTimeouts {
static int tiny_timeout_ms_;
static int action_timeout_ms_;
static int action_max_timeout_ms_;
+ static int test_launcher_unit_timeout_ms_;
static int test_launcher_timeout_ms_;
DISALLOW_IMPLICIT_CONSTRUCTORS(TestTimeouts);
« no previous file with comments | « base/test/test_switches.cc ('k') | base/test/test_timeouts.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698